Learn R Programming

BayesPPDSurv (version 1.0.3)

melanoma: Melanoma Clinical Trials E1684 and E1690

Description

A dataset for the E1684 clinical trial (1996) and the E1690 clinical trial (2000) conducted to assess the utility of interferon alfa-2b (INF) as an adjuvant therapy following surgery for deep primary or regionally metastatic melanoma. This dataset contains subjects in disease stage four only, i.e., regional lymph node recurrence at any interval after appropriate surgery for primary melanoma of any depth.

Usage

melanoma

Arguments

Format

A data frame with 381 rows and 5 variables:

study

study number (1684 or 1690)

failtime

time to relapse in years

rfscens

censoring indicator for time to relapse (0 = did not relapse, 1 = relapsed)

trt

treatment (1 if IFN and 0 if Observation)

stratum

stratum index (1 if number of positive nodes <= 2 and 2 if number of positive nodes >= 3