- time
Vector of follow up times.
- event
Vector of status indicators. Normally 0=alive and 1=dead.
- X
Matrix of covariates. The first column must be the treatment indicator.
- S
Vector of integers, where each integer represents the stratum that the subject belongs to. For example, if there are three strata, S can take values 1, 2 or 3.
- historical
List of historical dataset(s). East historical dataset is stored in a list which contains four named elements: time, event, X and S.
time is a vector of follow up times.
event is a vector of status indicators. Normally 0=alive and 1=dead.
X is a matrix of covariates. The first column must be the treatment indicator.
S is a vector of integers, where each integer represents the stratum that the subject belongs to. For example, if there are three strata, S can take values 1, 2 or 3.
- a0
Vector containing numbers between 0 and 1 indicating the discounting parameter value for each historical dataset. The length of the vector should be equal to the length of historical.
- n.intervals
Vector of integers, indicating the number of intervals for the baseline hazards for each stratum. The length of the vector should be equal to the total number of strata.
- change.points
List of vectors. Each vector in the list contains the change points for the baseline hazards for each stratum. The length of the list should be equal to the total number of strata.
For a given stratum, if there is only one interval, then change.points should be NULL for that stratum.
By default, we assign the change points so that the same number of events are observed in all the intervals in the pooled current and historical data.
- shared.blh
Logical value indicating whether baseline hazard parameters are shared between the current and historical data. If TRUE, baseline hazard parameters are shared. The default value is FALSE.
- prior.beta
Prior used for \(\beta\). The choices are "Uniform" and "Normal". If prior.beta is "Uniform", the uniform improper prior is used.
If prior.beta is "Normal", independent normal priors are used for each element of \(\beta\). The default choice is "Normal".
- prior.beta.mean
(Only applies if prior.beta is "Normal") vector of means of the normal prior on \(\beta\). The default value is zero for all the elements of \(\beta\).
- prior.beta.sd
(Only applies if prior.beta is "Normal") vector of standard deviations of the normal prior on \(\beta\). The default value is 10^3 for all the elements of \(\beta\).
- prior.lambda
Prior used for \(\lambda\). The choices are "Gamma", "Log-normal" and "Improper". The default choice is "Gamma".
If prior.lambda is "Gamma", then the prior on the first element of \(\lambda\) is
Gamma(shape=prior.lambda.hp1[1], rate=prior.lambda.hp2[1]).
If prior.lambda is "Log-normal", then the prior on the first element of \(\lambda\) is Log-normal(mean=prior.lambda.hp1[1], sd=prior.lambda.hp2[1]).
If prior.lambda is "Improper", then the prior on each element of \(\lambda\) is the improper prior \(\lambda^{-1}\).
- prior.lambda.hp1
(Only applies if prior.lambda is "Gamma" or "Log-normal") Vector of first hyperparameters of the prior on \(\lambda\).
The length of the vector should be equal to the dimension of \(\lambda\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda\).
- prior.lambda.hp2
(Only applies if prior.lambda is "Gamma" or "Log-normal") Vector of second hyperparameters of the prior on \(\lambda\).
The length of the vector should be equal to the dimension of \(\lambda\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda\).
- prior.lambda0.hp1
(Only applies if shared.blh is FALSE and if prior.lambda is "Gamma" or "Log-normal") Vector of first hyperparameters of the prior on \(\lambda_0\).
We assume the same distribution choice for the prior for \(\lambda_0\) and \(\lambda\).
The length of the vector should be equal to the dimension of \(\lambda_0\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda_0\).
- prior.lambda0.hp2
(Only applies if shared.blh is FALSE and if prior.lambda is "Gamma" or "Log-normal") Vector of second hyperparameters of the prior on \(\lambda_0\).
We assume the same distribution choice for the prior for \(\lambda_0\) and \(\lambda\).
The length of the vector should be equal to the dimension of \(\lambda_0\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda_0\).
- lower.limits
Vector of lower limits for parameters (\(\beta\), \(\lambda\), and \(\lambda_0\), in this order) to be used by the slice sampler. The length of the vector should be equal to the total number of parameters. The default is -100 for \(\beta\) and 0 for \(\lambda\) and \(\lambda_0\) (may not be appropriate for all situations).
- upper.limits
Vector of upper limits for parameters (\(\beta\), \(\lambda\), and \(\lambda_0\), in this order) to be used by the slice sampler. The length of the vector should be equal to the total number of parameters. The default is 100 for all parameters (may not be appropriate for all situations).
- slice.widths
Vector of initial slice widths for parameters (\(\beta\), \(\lambda\), and \(\lambda_0\), in this order) to be used by the slice sampler. The length of the vector should be equal to the total number of parameters. The default is 0.1 for all parameters (may not be appropriate for all situations).
- current.data
Logical value indicating whether current data is included. The default is TRUE. If FALSE, only historical data is included in the analysis,
and the posterior samples can be used as a discrete approximation to the sampling prior in
power.phm.fixed.a0 and power.phm.random.a0.
- nMC
Number of iterations (excluding burn-in samples) for the slice sampler. The default is 10,000.
- nBI
Number of burn-in samples for the slice sampler. The default is 250.