- historical
List of historical dataset(s). East historical dataset is stored in a list which contains four named elements: time, event, X and S.
time is a vector of follow up times.
event is a vector of status indicators. Normally 0=alive and 1=dead.
X is a matrix of covariates. The first column must be the treatment indicator.
S is a vector of integers, where each integer represents the stratum that the subject belongs to. For example, if there are three strata, S can take values 1, 2 or 3.
- n.subjects
Number of subjects enrolled.
- n.events
Number of events at which the trial will stop.
- n.intervals
Vector of integers, indicating the number of intervals for the baseline hazards for each stratum. The length of the vector should be equal to the total number of strata.
- change.points
List of vectors. Each vector in the list contains the change points for the baseline hazards for each stratum. The length of the list should be equal to the total number of strata.
For a given stratum, if there is only one interval, then change.points should be NULL for that stratum. By default, we assign the change points so that the same number of events are observed in all the intervals in the historical data.
These change points are used for data generation. The change points used during model fitting are assigned by default so that the same number of events are observed in all the intervals in the pooled historical and generated current data.
- samp.prior.beta
Matrix of possible values of \(\beta\) to sample (with replacement) from. Each row is a possible \(\beta\) vector (a realization from the sampling prior for \(\beta\)).
- samp.prior.lambda
List of matrices, where each matrix represents the sampling prior for the baseline hazards for each stratum. The number of columns of each matrix should be equal to the number of intervals for that stratum.
- dist.enroll
Distribution for enrollment times. The choices are "Uniform" or "Exponential".
- param.enroll
Parameter for the distribution of enrollment times. If dist.enroll is "Uniform", the enrollment times follow Unif(0, param.enroll). If dist.enroll is "Exponential",
the enrollment times follow Exponential(rate=param.enroll).
- rand.prob
Randomization probability for the treated group. The default value is 0.5.
- prob.drop
Probability of subjects dropping out of the study (non-administrative censoring). The default value is zero.
- param.drop
Parameter for dropout time simulations. The dropout times follow Unif(0, param.drop). The default value is zero.
- dist.csr
Distribution for (administrative) censorship times. The choices are "Uniform", "Constant" and "Exponential". The default choice is "Constant".
- param.csr
Parameter for the (administrative) censorship times. If dist.csr is "Uniform", the censorship times follow Unif(0, param.csr).
If dist.csr is "Constant", the censorship times of all subjects are equal to param.csr.
If dist.csr is "Exponential", the censorship times follow Exponential(rate=param.csr).
The default value is 10^4.
- min.follow.up
Minimum amount of time for which subjects are followed up. The default value is zero.
- max.follow.up
Maximum amount of time for which subjects are followed up. The default value is 10^4.
- prior.beta.mvn
List of multivariate normal approximations of the normalized power prior for \(\beta\). Each element in the list is a list with three components,
the mean vector, the covariance matrix and the weight of the multivariate normal distribution. The normalized power prior for \(\beta\)
is approximated by the weighted mixture of the multivariate normal distributions provided. By default (prior.beta.mvn=NULL), a single multivariate normal distribution is assumed.
The user can use the approximate.prior.beta function to obtain samples of \(\beta\) from the normalized power prior, and use any mixture of multivariate normals to approximate
the normalized power prior for \(\beta\).
- prior.beta.mean
(Only applies if prior.beta.mvn=NULL) Vector of means of the normal initial prior on \(\beta\). The default value is zero for all the elements of \(\beta\).
- prior.beta.sd
(Only applies if prior.beta.mvn=NULL) Vector of standard deviations of the normal initial prior on \(\beta\). The default value is 10^3 for all the elements of \(\beta\).
- prior.lambda0.hp1
(Only applies if prior.beta.mvn=NULL) Vector of first hyperparameters of the Gamma prior on \(\lambda_0\).
The length of the vector should be equal to the dimension of \(\lambda_0\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda_0\).
- prior.lambda0.hp2
(Only applies if prior.beta.mvn=NULL) Vector of second hyperparameters of the Gamma prior on \(\lambda_0\).
The length of the vector should be equal to the dimension of \(\lambda_0\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda_0\).
- prior.a0.shape1
(Only applies if prior.beta.mvn=NULL) Vector of the first shape parameters of the independent beta priors for \(a_0\). The length of the vector should be equal to the number of historical datasets. The default is a vector of one's.
- prior.a0.shape2
(Only applies if prior.beta.mvn=NULL) Vector of the second shape parameters of the independent beta priors for \(a_0\). The length of the vector should be equal to the number of historical datasets. The default is a vector of one's.
- prior.lambda.hp1
Vector of first hyperparameters of the Gamma prior on \(\lambda\).
The length of the vector should be equal to the dimension of \(\lambda\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda\).
- prior.lambda.hp2
Vector of second hyperparameters of the Gamma prior on \(\lambda\).
The length of the vector should be equal to the dimension of \(\lambda\), i.e., the total number of intervals for all strata. The default value is 10^(-5) for all the elements of \(\lambda\).
- lower.limits
Vector of lower limits for parameters (\(\beta\) and \(\lambda\), in this order) to be used by the slice sampler. The length of the vector should be equal to the total number of parameters. The default is -100 for \(\beta\) and 0 for \(\lambda\) (may not be appropriate for all situations).
- upper.limits
Vector of upper limits for parameters (\(\beta\) and \(\lambda\), in this order) to be used by the slice sampler. The length of the vector should be equal to the total number of parameters. The default is 100 for all parameters (may not be appropriate for all situations).
- slice.widths
Vector of initial slice widths for parameters (\(\beta\) and \(\lambda\), in this order) to be used by the slice sampler. The length of the vector should be equal to the total number of parameters. The default is 0.1 for all parameters (may not be appropriate for all situations).
- nMC
Number of iterations (excluding burn-in samples) for the slice sampler. The default is 10,000.
- nBI
Number of burn-in samples for the slice sampler. The default is 250.
- delta
Prespecified constant that defines the boundary of the null hypothesis. The default is zero.
- nullspace.ineq
Character string specifying the inequality of the null hypothesis. The options are ">" and "<". If ">" is specified, the null hypothesis is \(H_0\): \(\beta_1\) \(\ge\) \(\delta\). If "<" is specified, the null hypothesis is \(H_0\): \(\beta_1\) \(\le\) \(\delta\). The default choice is ">".
- gamma
Posterior probability threshold for rejecting the null. The null hypothesis is rejected if posterior probability is greater gamma. The default is 0.95.
- N
Number of simulated datasets to generate. The default is 10,000.